==> tine20-inventory_2019.12.5.tar.bz2: Inventory/js/Inventory-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: vi\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Inventory item, Inventory items"
: [
  "Quản lý kho"

]
, "Inventory item list, Inventory item lists"
: [
  ""

]
, "Name"
: "Tên"

, "Status"
: "Trạng thái"

, "Inventory ID"
: "Mã kho"

, "Description"
: "Mô tả"

, "Location"
: "Địa điểm"

, "Invoice date"
: "Ngày hóa đơn"

, "Invoice"
: "Hóa đơn"

, "Price"
: "Giá"

, "Cost Center"
: ""

, "Warranty"
: "Bảo hành"

, "Item added"
: "Hàng đã thêm"

, "Item removed"
: "Hàng đã xóa"

, "Deprecate"
: ""

, "The active number must be less than or equal total number."
: "Số luân chuyển phải nhỏ hơn hoặc bằng tổng số"

, "General"
: "Chung"

, "ID"
: "Mã"

, "Enter description"
: "Nhập mô tả"

, "Added"
: "Đã thêm"

, "Removed"
: "Đã xóa"

, "Total number"
: "Số tổng"

, "Available number"
: "Số sẵn có"

, "Accounting"
: "Thống kê"

, "Cost center"
: ""

, "Depreciate"
: "Giảm giá"

, "Default Inventory Item Container"
: "Bộ chưa kho hàng mặc định"

, "The default container for new items"
: "Bộ chứa mặc định cho mục mới"

, "Inventory Status Available"
: "Trạng thái sẵn sàng của kho"

, "Possible status."
: "Trạng thái có thể"

, "ordered"
: "đã xếp lại"

, "available"
: "sẵn sàng"

, "defect"
: "thiếu"

, "missing"
: "thất lạc"

, "removed"
: "đã xóa"

, "unknown"
: "không rõ"

, "Inventory CSV import"
: "Nhập dữ liệu kiểm kê CSV"

, "Import list (###CURRENTDATE###)"
: "Nhập danh sách (###CURRENTDATE###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Mục được nhập trong ###CURRENTDATE### tại ###CURRENTTIME### bởi ###USERFULLNAME###"

, "All Inventory Items"
: "Tất cả hàng trong kho"

, "All existing Inventory Items"
: "Tất cả hàng còn lại trong kho"

, "Inventory"
: "Kho"

, "Inventory item"
: "Quản lý kho"

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-inventory_2020.08.8.tar.bz2: Inventory/js/Inventory-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Inventory Item Container"
: "Bộ chưa kho hàng mặc định"

, "The default container for new items"
: "Bộ chứa mặc định cho mục mới"

, "The active number must be less than or equal total number."
: "Số luân chuyển phải nhỏ hơn hoặc bằng tổng số"

, "General"
: "Chung"

, "ID"
: "Mã"

, "Name"
: "Tên"

, "Description"
: "Mô tả"

, "Enter description"
: "Nhập mô tả"

, "Location"
: "Địa điểm"

, "Added"
: "Đã thêm"

, "Warranty"
: "Bảo hành"

, "Removed"
: "Đã xóa"

, "Total number"
: "Số tổng"

, "Available number"
: "Số sẵn có"

, "Status"
: "Trạng thái"

, "Accounting"
: "Thống kê"

, "Price"
: "Giá"

, "Cost center"
: ""

, "Invoice"
: "Hóa đơn"

, "Invoice date"
: "Ngày hóa đơn"

, "Depreciate"
: "Giảm giá"

, "All Inventory Items"
: "Tất cả hàng trong kho"

, "All existing Inventory Items"
: "Tất cả hàng còn lại trong kho"

, "Inventory"
: "Kho"

, "Inventory Status Available"
: "Trạng thái sẵn sàng của kho"

, "Possible status."
: "Trạng thái có thể"

, "ordered"
: "đã xếp lại"

, "available"
: "sẵn sàng"

, "defect"
: "thiếu"

, "missing"
: "thất lạc"

, "removed"
: "đã xóa"

, "unknown"
: "không rõ"

, "Inventory item, Inventory items"
: [
  "Quản lý kho"

]
, "Inventory item list, Inventory item lists"
: [
  ""

]
, "Inventory ID"
: "Mã kho"

, "Cost Center"
: ""

, "Item added"
: "Hàng đã thêm"

, "Item removed"
: "Hàng đã xóa"

, "Inventory CSV import"
: "Nhập dữ liệu kiểm kê CSV"

, "Import list (###CURRENTDATE###)"
: "Nhập danh sách (###CURRENTDATE###)"

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Mục được nhập trong ###CURRENTDATE### tại ###CURRENTTIME### bởi ###USERFULLNAME###"

, "Inventory item"
: "Quản lý kho"

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
